""" mitol.google_sheets_refunds """
default_app_config = "mitol.google_sheets_refunds.apps.GoogleSheetsRefundsApp"

__version__ = "2023.12.19"
__distributionname__ = "mitol-django-google-sheets-refunds"
